import os
__version__ = "2021.6.16"
RXN_ROOT = os.path.dirname(os.path.abspath(__file__))
RXN_FILES = os.path.join(RXN_ROOT, 'files')
